@@ -6,8 +6,7 @@
  *
  */
 
-#ifndef AKONADI_SEARCH_PIM_CONTACTCOMPLETER_H
-#define AKONADI_SEARCH_PIM_CONTACTCOMPLETER_H
+#pragma once
 
 #include "search_pim_export.h"
 #include <QString>
@@ -25,7 +24,7 @@ class AKONADI_SEARCH_PIM_EXPORT ContactCompleter
 public:
     explicit ContactCompleter(const QString &prefix, int limit = 10);
 
-    Q_REQUIRED_RESULT QStringList complete();
+    [[nodiscard]] QStringList complete();
 
 private:
     const QString m_prefix;
@@ -34,4 +33,3 @@ private:
 }
 }
 }
-#endif // AKONADI_SEARCH_PIM_CONTACTCOMPLETER_H
